==> kleinod-0.36-sources.jar: de/pfabulist/kleinod/nio/PathIKWID.java <==
package de.pfabulist.kleinod.nio;//package de.pfabulist.kleinod.nio;
//
//import edu.umd.cs.findbugs.annotations.SuppressFBWarnings;
//
//import javax.annotation.Nullable;
//import java.nio.file.Path;
//
//import static de.pfabulist.kleinod.nio.Pathss.isRoot;
//
///**
// * Copyright (c) 2006 - 2016, Stephan Pfab
// * SPDX-License-Identifier: BSD-2-Clause
// */
//
///**
// * I know what I am doing class
// * clearly state why you think a specific call is safe
// * change NullpointerException into something more meaningful
// * plus avoid findbugs false positives
// */
//@SuppressWarnings( "unchecked" )
//@SuppressFBWarnings( "NP_NULL_ON_SOME_PATH_FROM_RETURN_VALUE" )
//public final class PathIKWID {
//
//    private PathIKWID() {}
//
//    // findbugs can't understand that absolute Paths have a root
//    public static <T extends Path> T absoluteGetRoot(  T path ) {
//        if ( !path.isAbsolute() ) {
//            throw  new IllegalArgumentException( "path is not absolute " + path );
//        }
//
//        //noinspection ConstantConditions
//        return (T) path.getRoot();
//    }
//
//    /**
//     * Path.getParent but checks that there is parent first and throws
//     * a different Exception (with more info)
//     */
//    public static <T extends Path> T childGetParent( T path) {
//        @Nullable T parent = (T) path.getParent();
//
//        if ( parent == null ) {
//            throw new IllegalArgumentException( "path is no child: " + path );
//        }
//
//        return parent;
//    }
//
//    public static <T extends Path> T namedGetFilename( T path) {
//        @Nullable T name = (T) path.getFileName();
//
//        if ( name == null ) {
//            if ( isRoot( path )) {
//                throw new IllegalArgumentException( "root has no filename" );
//            }
//
//            throw new IllegalArgumentException( "default path has no filename" );
//        }
//
//        return name;
//    }
//
//}

==> kleinod-0.37-sources.jar: de/pfabulist/kleinod/nio/PathIKWID.java <==
package de.pfabulist.kleinod.nio;//package de.pfabulist.kleinod.nio;
//
//import edu.umd.cs.findbugs.annotations.SuppressFBWarnings;
//
//import javax.annotation.Nullable;
//import java.nio.file.Path;
//
//import static de.pfabulist.kleinod.nio.Pathss.isRoot;
//
///**
// * Copyright (c) 2006 - 2016, Stephan Pfab
// * SPDX-License-Identifier: BSD-2-Clause
// */
//
///**
// * I know what I am doing class
// * clearly state why you think a specific call is safe
// * change NullpointerException into something more meaningful
// * plus avoid findbugs false positives
// */
//@SuppressWarnings( "unchecked" )
//@SuppressFBWarnings( "NP_NULL_ON_SOME_PATH_FROM_RETURN_VALUE" )
//public final class PathIKWID {
//
//    private PathIKWID() {}
//
//    // findbugs can't understand that absolute Paths have a root
//    public static <T extends Path> T absoluteGetRoot(  T path ) {
//        if ( !path.isAbsolute_() ) {
//            throw  new IllegalArgumentException( "path is not absolute " + path );
//        }
//
//        //noinspection ConstantConditions
//        return (T) path.getRoot_o();
//    }
//
//    /**
//     * Path.getParent but checks that there is parent first and throws
//     * a different Exception (with more info)
//     */
//    public static <T extends Path> T childGetParent( T path) {
//        @Nullable T parent = (T) path.getParent();
//
//        if ( parent == null ) {
//            throw new IllegalArgumentException( "path is no child: " + path );
//        }
//
//        return parent;
//    }
//
//    public static <T extends Path> T namedGetFilename( T path) {
//        @Nullable T name = (T) path.getFileName();
//
//        if ( name == null ) {
//            if ( isRoot( path )) {
//                throw new IllegalArgumentException( "root has no filename" );
//            }
//
//            throw new IllegalArgumentException( "default path has no filename" );
//        }
//
//        return name;
//    }
//
//}
